@@ -6,12 +6,15 @@ from __future__ import absolute_import
 from lusid.api.aggregation_api import AggregationApi
 from lusid.api.allocations_api import AllocationsApi
 from lusid.api.application_metadata_api import ApplicationMetadataApi
+from lusid.api.calendars_api import CalendarsApi
 from lusid.api.complex_market_data_api import ComplexMarketDataApi
 from lusid.api.configuration_recipe_api import ConfigurationRecipeApi
+from lusid.api.corporate_action_sources_api import CorporateActionSourcesApi
 from lusid.api.cut_label_definitions_api import CutLabelDefinitionsApi
 from lusid.api.data_types_api import DataTypesApi
 from lusid.api.derived_transaction_portfolios_api import DerivedTransactionPortfoliosApi
 from lusid.api.entities_api import EntitiesApi
+from lusid.api.executions_api import ExecutionsApi
 from lusid.api.instruments_api import InstrumentsApi
 from lusid.api.legal_entities_api import LegalEntitiesApi
 from lusid.api.orders_api import OrdersApi
@@ -22,7 +25,10 @@ from lusid.api.property_definitions_api import PropertyDefinitionsApi
 from lusid.api.quotes_api import QuotesApi
 from lusid.api.reconciliations_api import ReconciliationsApi
 from lusid.api.reference_portfolio_api import ReferencePortfolioApi
+from lusid.api.relationship_definitions_api import RelationshipDefinitionsApi
+from lusid.api.relationships_api import RelationshipsApi
 from lusid.api.scopes_api import ScopesApi
 from lusid.api.search_api import SearchApi
+from lusid.api.sequences_api import SequencesApi
 from lusid.api.system_configuration_api import SystemConfigurationApi
 from lusid.api.transaction_portfolios_api import TransactionPortfoliosApi
